@@ -1,25 +1,10 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
-                  2005-2008 Frank Osterfeld <osterfeld@kde.org>
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    SPDX-FileCopyrightText: 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
+    SPDX-FileCopyrightText: 2005-2008 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "articlelistview.h"
@@ -35,7 +20,6 @@
 #include <QDateTime>
 #include <QIcon>
 #include <KLocalizedString>
-#include <QUrl>
 #include <QMenu>
 #include <KColorScheme>
 #include <QLocale>
@@ -144,14 +128,14 @@ void ArticleListView::setArticleModel(ArticleModel *model)
     m_proxy->setSourceModel(model);
     m_proxy->setSortRole(ArticleModel::SortRole);
     m_proxy->setFilters(m_matchers);
-    FilterDeletedProxyModel *const proxy2 = new FilterDeletedProxyModel(model);
+    auto *const proxy2 = new FilterDeletedProxyModel(model);
     proxy2->setSortRole(ArticleModel::SortRole);
     proxy2->setSourceModel(m_proxy);
 
     connect(model, &QAbstractItemModel::rowsInserted,
             m_proxy.data(), &QSortFilterProxyModel::invalidate);
 
-    FilterColumnsProxyModel *const columnsProxy = new FilterColumnsProxyModel(model);
+    auto *const columnsProxy = new FilterColumnsProxyModel(model);
     columnsProxy->setSortRole(ArticleModel::SortRole);
     columnsProxy->setSourceModel(proxy2);
     columnsProxy->setColumnEnabled(ArticleModel::ItemTitleColumn);
@@ -415,7 +399,7 @@ void ArticleListView::mousePressEvent(QMouseEvent *ev)
 void ArticleListView::contextMenuEvent(QContextMenuEvent *event)
 {
     QWidget *w = ActionManager::getInstance()->container(QStringLiteral("article_popup"));
-    QMenu *popup = qobject_cast<QMenu *>(w);
+    auto *popup = qobject_cast<QMenu *>(w);
     if (popup) {
         popup->exec(event->globalPos());
     }
