@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "articleviewerwebenginewidgetng.h"
@@ -58,23 +45,21 @@ InvokeWrapper<Arg, R, C> invoke(R *receiver, void (C::*memberFun)(Arg))
 
 ArticleViewerWebEngineWidgetNg::ArticleViewerWebEngineWidgetNg(ArticleViewerWebEngine *customViewer, KActionCollection *ac, QWidget *parent)
     : QWidget(parent)
-    , mCurrentPrinter(nullptr)
+    , mArticleViewerNg(customViewer)
 {
-    mArticleViewerNg = customViewer;
     initializeLayout(ac);
 }
 
 ArticleViewerWebEngineWidgetNg::ArticleViewerWebEngineWidgetNg(KActionCollection *ac, QWidget *parent)
     : QWidget(parent)
     , mArticleViewerNg(nullptr)
-    , mCurrentPrinter(nullptr)
 {
     initializeLayout(ac);
 }
 
 void ArticleViewerWebEngineWidgetNg::initializeLayout(KActionCollection *ac)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
 
     mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
@@ -178,7 +163,7 @@ void ArticleViewerWebEngineWidgetNg::slotOpenInBrowser()
 {
     const QUrl currentUrl(mArticleViewerNg->url());
     if (currentUrl.isLocalFile()) {
-        WebEngineViewer::WebEngineExportHtmlPageJob *job = new WebEngineViewer::WebEngineExportHtmlPageJob;
+        auto *job = new WebEngineViewer::WebEngineExportHtmlPageJob;
         job->setEngineView(mArticleViewerNg);
         connect(job, &WebEngineViewer::WebEngineExportHtmlPageJob::failed, this, &ArticleViewerWebEngineWidgetNg::slotExportHtmlPageFailed);
         connect(job, &WebEngineViewer::WebEngineExportHtmlPageJob::success, this, &ArticleViewerWebEngineWidgetNg::slotExportHtmlPageSuccess);
