@@ -1,26 +1,10 @@
 /*
     This file is part of Akregator.
 
-    Copyright (C) 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
-                  2004-2005 Frank Osterfeld <osterfeld@kde.org>
+    SPDX-FileCopyrightText: 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
+    SPDX-FileCopyrightText: 2004-2005 Frank Osterfeld <osterfeld@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-    As a special exception, permission is given to link this program
-    with any edition of Qt, and distribute the resulting executable,
-    without including the source code for Qt in the source distribution.
+    SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "folder.h"
 #include "article.h"
@@ -318,7 +302,7 @@ void Folder::updateUnreadCount() const
 
 KJob *Folder::createMarkAsReadJob()
 {
-    CompositeJob *job = new CompositeJob;
+    auto *job = new CompositeJob;
     const auto f = feeds();
     for (Feed *const i : f) {
         job->addSubjob(i->createMarkAsReadJob());
@@ -456,7 +440,7 @@ QList<const TreeNode *> Folder::namedChildren(const QString &title) const
         if (child->title() == title) {
             nodeList.append(child);
         }
-        const Folder *fld = dynamic_cast<const Folder *>(child);
+        const auto *fld = dynamic_cast<const Folder *>(child);
         if (fld) {
             nodeList += fld->namedChildren(title);
         }
@@ -472,7 +456,7 @@ QList<TreeNode *> Folder::namedChildren(const QString &title)
         if (child->title() == title) {
             nodeList.append(child);
         }
-        Folder *const fld = qobject_cast<Folder *>(child);
+        auto *const fld = qobject_cast<Folder *>(child);
         if (fld) {
             nodeList += fld->namedChildren(title);
         }
